pub fn build_static_constraints(
bn: &BooleanNetwork,
encoder: &BddParameterEncoder
) -> BddExpand description
Build a Bdd which describes all valuations satisfying the static constraints
of the given BooleanNetwork.
pub fn build_static_constraints(
bn: &BooleanNetwork,
encoder: &BddParameterEncoder
) -> BddBuild a Bdd which describes all valuations satisfying the static constraints
of the given BooleanNetwork.